@@ -530,6 +530,27 @@ class QcacheTotalBlocks(StatuBase):
     """
     statu_name="Qcache_total_blocks"
 
+class SlowQueries(StatuBase):
+    """
+    he number of queries that have taken more than long_query_time seconds. 
+    This counter increments regardless of whether the slow query log is enabled. For information about that log
+    """
+    statu_name="Slow_queries"
+
+class TableLocksImmediate(StatuBase):
+    """
+    The number of times that a request for a table lock could be granted immediately.
+    """
+    statu_name="Table_locks_immediate"
+
+class TableLocksWaited(StatuBase):
+    """The number of times that a request for a table lock could not be granted immediately and a wait was needed. 
+    If this is high and you have performance problems, you should first optimize your queries, 
+    and then either split your table or tables or use replication.
+    """
+    statu_name="Table_locks_waited"
+
+
 class TableOpenCacheOverflows(StatuBase):
     """
     The number of overflows for the open tables cache. This is the number of times, 
